@@ -34,8 +34,8 @@ public:
     explicit BinaryClockWidget(QWidget *parent = 0);
     ~BinaryClockWidget();
 
-    void setBaseSize(int size);
-    void setBorder(int border);
+    void setLedSize(int size);
+    void setLedBorder(int border);
     void setLedColor(const QColor &color);
 
     QSize sizeHint();
