@@ -23,7 +23,3 @@ ClockWidget::ClockWidget(QWidget *parent) :
     QWidget(parent)
 {
 }
-
-void ClockWidget::mouseReleaseEvent(QMouseEvent */*event*/){
-    emit clicked();
-}
