@@ -21,7 +21,10 @@
 #include <QtGui/QApplication>
 
 #include "mainwidget.h"
+
+#ifdef Q_WS_MAEMO_5
 #include "qmaemo5homescreenadaptor.h"
+#endif
 
 int main(int argc, char *argv[])
 {
@@ -29,10 +32,12 @@ int main(int argc, char *argv[])
 
     MainWidget widget;
 
+#ifdef Q_WS_MAEMO_5
     QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&widget);
-
     adaptor->setSettingsAvailable(true);
     QObject::connect(adaptor, SIGNAL(settingsRequested()), &widget, SLOT(openSettingsDialog()));
+#endif
+
     widget.show();
     return a.exec();
 }
